<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" indent="yes"/>
	<xsl:param name="application_name"/>
	
	<xsl:template match="/">
		<helpfiles>
			<!-- Title page -->
			<file name="index.html">
				<html>
					<head>
						<title><xsl:value-of select="name"/><xsl:value-of select="$application_name"/><xsl:text> Help</xsl:text></title>
						<meta name="AppleTitle" content="{$application_name} Help"/>
						<meta name="AppleIcon" content="Help/{$application_name}16.png"/>
						</head>
					<body>
						<ul>
							<xsl:for-each select="helpbook/link">
								<li>
									<xsl:apply-templates select="."><xsl:with-param name="main_page" select="true()"/></xsl:apply-templates><br/>
									<!-- See note in link template for use of variable -->
									<xsl:variable name="requested_page_id" select="@href"/>
									<xsl:value-of select="/helpbook/page[@id=$requested_page_id]/summary"/>
									</li>
								</xsl:for-each>
							</ul>
						</body>
					</html>
				</file>
			
			<!-- Generate pages -->
			<xsl:apply-templates select="helpbook/page"/>
			</helpfiles>
		</xsl:template>
	
	<xsl:template match="page">
		<file name="pages/{@id}.html">
			<html>
				<head><title><xsl:value-of select="name"/></title></head>
				<body>
					<xsl:apply-templates select="content"/>
					</body>
				</html>
			</file>
		</xsl:template>
	
	<xsl:template match="link">
		<xsl:param name="main_page"/>
		<xsl:variable name="page_url">
			<xsl:choose>
				<xsl:when test="$main_page">
					<xsl:text>pages/</xsl:text><xsl:value-of select="@href"/><xsl:text>.html</xsl:text>
					</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="@href"/><xsl:text>.html</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
		<a href="{$page_url}">
			<xsl:choose>
				<xsl:when test="text()"><xsl:value-of select="text()"/></xsl:when>
				<xsl:otherwise>
					<!-- couln't figure out how to query @id='{@href}' directly without variable -->
					<xsl:variable name="requested_page_id" select="@href"/>
					<xsl:value-of select="/helpbook/page[@id=$requested_page_id]/name"/>
					</xsl:otherwise>
				</xsl:choose>
			</a>
		</xsl:template>
	
	<!-- deep copy elements with HTML bodies -->
	<xsl:template match="*">
		<xsl:element name="{name()}">
			<xsl:apply-templates select="@*|*|text()"/>
			</xsl:element>
	 	</xsl:template>
	<xsl:template match="@*">
		<xsl:attribute name="{name()}">
			<xsl:value-of select="."/>
			</xsl:attribute>
		</xsl:template>
	<xsl:template match="text()">
		<xsl:copy>
			<xsl:apply-templates select="node()"/>
			</xsl:copy>
		</xsl:template>
	
	</xsl:stylesheet>