<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="text"/>
	<xsl:param name="fileset"/>
	
	<!-- Define root match to avoid default rules inserting extra text (usually just linefeeds) -->
	<xsl:template match="/">
		<xsl:if test="not($fileset)">
			<xsl:message terminate="yes">You must provide a 'fileset' parameter.</xsl:message>
			</xsl:if>
		<xsl:text>#! /bin/sh&#10;</xsl:text>
		<xsl:apply-templates select="helpfiles/file"/>
		</xsl:template>
	
	<xsl:template match="file">
		<xsl:variable name="escaped_filename">
			<xsl:value-of select="@name"/>
		<!-- Shell escaping not necessary right now, disabling for cleaner output
			<xsl:call-template name="shell-escape">
				<xsl:with-param name="text"><xsl:value-of select="@name"/></xsl:with-param>
				</xsl:call-template>
				-->
			</xsl:variable>
		
		<xsl:text>xsltproc </xsl:text>
		
		<xsl:text>--stringparam filename </xsl:text>
		<xsl:value-of select="$escaped_filename"/>
		<xsl:text> </xsl:text>
		
		<xsl:text>extract_file.xsl </xsl:text>
		
		<xsl:value-of select="$fileset"/>
		
		<xsl:text> > </xsl:text>
		<xsl:value-of select="$escaped_filename"/>
		<xsl:text>&#10;</xsl:text>
		</xsl:template>
	
	<xsl:template name="shell-escape">
		<xsl:param name="text"/>
		<xsl:text>&apos;</xsl:text>
		<xsl:call-template name="replace-substring">
			<xsl:with-param name="from">&apos;</xsl:with-param>
			<xsl:with-param name="to">&apos;\&apos;&apos;</xsl:with-param>
			<xsl:with-param name="value" select="$text" />
			</xsl:call-template>
		<xsl:text>&apos;</xsl:text>
		</xsl:template>
	
	<xsl:template name="replace-substring">
		<xsl:param name="value" />
		<xsl:param name="from" />
		<xsl:param name="to" />
		<xsl:choose>
			<xsl:when test="contains($value,$from)">
				<xsl:value-of select="substring-before($value,$from)" />
				<xsl:value-of select="$to" />
				<xsl:call-template name="replace-substring">
					<xsl:with-param name="value" select="substring-after($value,$from)" />
					<xsl:with-param name="from" select="$from" />
					<xsl:with-param name="to" select="$to" />
					</xsl:call-template>
				</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$value" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:template>
	
	</xsl:stylesheet>


